@@ -238,7 +238,7 @@ class ImageRecognition(object):
             batch_size {integer} -- the size of the batch
             image_name_list {list of string} -- the list of image name
         """
-        file_list = get_filenames(os.path.join(dataset_path + self.classes))
+        file_list = get_filenames(os.path.join(dataset_path + self.classes[0]))
         self.file_num = len(file_list) * len(self.classes)
         self.tmp_batch_size = batch_size
 
@@ -312,7 +312,8 @@ class ImageRecognition(object):
                         cost_tensor,
                         out_tensor): 
         x_val, y_val = next(val_generator)
-        iteration_needed = math.ceil(self.file_num / self.batch_generator)
+        iteration_needed = math.ceil(self.file_num / self.tmp_batch_size)
+        print (iteration_needed)
 
         losses = [] 
         accs = [] 
